Learn R Programming

tvm (version 0.1)

disc_to_german: Converts a discount factor curve to a german loan rate curve

Description

Converts a discount factor curve to a german loan rate curve

Usage

disc_to_german(disc)

Arguments

disc
The discount factor curve